SystemOrganization addCategory: #'OCMS-Database'!

Object subclass: #Coursewares
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Database'!

!Coursewares class methodsFor: 'as yet unclassified' stamp: 'has 5/26/2013 11:59'!
add: aCourseware
	aCourseware id: self incrementId.
	OCMSDB commit: [self database add: aCourseware].! !

!Coursewares class methodsFor: 'as yet unclassified' stamp: 'has 5/25/2013 20:15'!
database
	^ OCMSDB root at: 'coursewares'.! !

!Coursewares class methodsFor: 'as yet unclassified' stamp: 'has 6/2/2013 19:26'!
getAll
	"I return a collection with all coursewares in database"
	| reader |
	reader := self database. " asOrderedCollection."
	^ reader.! !

!Coursewares class methodsFor: 'as yet unclassified' stamp: 'has 6/2/2013 16:45'!
incrementId
	| maxCourseware newId |
	newId := 0.
	(self database size > 0)
		ifTrue: [	maxCourseware := self database detectMax: #id.
				newId := maxCourseware id + 1]
		ifFalse: [newId := 1].
	^ newId.! !

!Coursewares class methodsFor: 'as yet unclassified' stamp: 'has 6/2/2013 19:31'!
remove: aCourseware
	(self database includes: aCourseware)
		ifTrue:[OCMSDB commit: [self database remove: aCourseware]]
		ifFalse:[self error: 'This courseware does not exist'].! !

!Coursewares class methodsFor: 'as yet unclassified' stamp: 'has 6/2/2013 10:19'!
searchById: anId
	"return a courseware with the id or nil"
	
	| reader |
	reader := self database where: [:each | each id = anId].
	(reader isEmpty not)
		ifTrue:[^ reader first].
		^ nil.! !

!Coursewares class methodsFor: 'as yet unclassified' stamp: 'has 6/2/2013 19:22'!
searchByTitle: aTitle
	"I return a collection with coursewares that contain the typed title"
	| reader |
	reader := self database where: [:each | each title from: aTitle to: aTitle maAlphabeticalNext].
	^ reader.! !

!Coursewares class methodsFor: 'as yet unclassified' stamp: 'has 6/2/2013 18:18'!
update: aCourseware
	(self database includes: aCourseware)
		ifTrue:[
				OCMSDB commit: [
					self database remove: aCourseware.
					self database add: aCourseware].
				]
		ifFalse:[self error: 'This courseware does not exist'].! !

Object subclass: #OCMSDB
	instanceVariableNames: 'session'
	classVariableNames: 'Default'
	poolDictionaries: ''
	category: 'OCMS-Database'!

!OCMSDB class methodsFor: 'as yet unclassified' stamp: 'has 6/2/2013 17:58'!
commit: anDBOperation
	self default session commit: anDBOperation.
	self session refresh.! !

!OCMSDB class methodsFor: 'as yet unclassified' stamp: 'has 5/25/2013 19:15'!
default
	^ Default ifNil: [Default := self new connect; yourself].! !

!OCMSDB class methodsFor: 'as yet unclassified' stamp: 'has 5/25/2013 20:33'!
release
	Default ifNil: [
		Default session disconnectAndClose.
		Default := nil.
		]! !

!OCMSDB class methodsFor: 'as yet unclassified' stamp: 'has 5/25/2013 19:22'!
root
	^ self session root! !

!OCMSDB class methodsFor: 'as yet unclassified' stamp: 'has 5/25/2013 19:20'!
session
	^ self default session! !

!OCMSDB class methodsFor: 'as yet unclassified' stamp: 'has 6/2/2013 17:53'!
updateDBObjects
	"I initialize MagmaCollection at the keys of OCMSDB if they do not exist"
	
	self commit:[
					((OCMSDB session root at: 'coursewares') isMemberOf: MagmaCollection)
						ifFalse:[self session root at: 'coursewares' put: MagmaCollection new.].
					((OCMSDB session root at: 'users') isMemberOf: MagmaCollection)
						ifFalse:[self session root at: 'users' put: MagmaCollection new.].
				]! !

!OCMSDB class methodsFor: 'as yet unclassified' stamp: 'has 6/2/2013 18:53'!
updateIndexes
	"I initialize indexes of DBObjects in OCMSDB if they do not exist"
	
	self commit:[
					((self session root at: 'coursewares') hasIndexNamed: #id)
						ifFalse:[(self session root at: 'coursewares') addIndex: (MaIntegerIndex attribute: #id)].
					((self session root at: 'coursewares') hasIndexNamed: #title)
						ifFalse:[(self session root at: 'coursewares') addIndex: (MaSearchStringIndex attribute: #title)].
					"((self session root at: 'coursewares') hasIndexNamed: #owner)
						ifFalse:[(self session root at: 'coursewares') addIndex: (MaSearchStringIndex attribute: #owner)]."
					((self session root at: 'users') hasIndexNamed: #login)
						ifFalse:[(self session root at: 'users') addIndex: (MaSearchStringIndex attribute: #login)].
					((self session root at: 'users') hasIndexNamed: #name)
						ifFalse:[(self session root at: 'users') addIndex: (MaSearchStringIndex attribute: #name)].

				]! !

!OCMSDB methodsFor: 'as yet unclassified' stamp: 'has 5/25/2013 19:18'!
connect
	session := (MagmaRemoteLocation
				host: 'localhost'
				port: 51001) newSession.
	session connectAs: 'higor'.! !

!OCMSDB methodsFor: 'as yet unclassified' stamp: 'has 5/25/2013 19:19'!
session
	^ session! !

Object subclass: #Users
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Database'!

!Users class methodsFor: 'as yet unclassified' stamp: 'has 6/2/2013 19:09'!
add: anUser
	(self loginExists: anUser)
		ifFalse:[OCMSDB commit:[self database add: anUser]]
		ifTrue:[self error: 'This login already exists.'].! !

!Users class methodsFor: 'as yet unclassified' stamp: 'has 6/2/2013 19:00'!
database
	^ OCMSDB root at: 'users'.! !

!Users class methodsFor: 'as yet unclassified' stamp: 'has 6/2/2013 19:26'!
getAll
	"I return a collection with all users in database"
	| reader |
	reader := self database. " asOrderedCollection."
	^ reader.! !

!Users class methodsFor: 'as yet unclassified' stamp: 'has 6/2/2013 19:20'!
loginExists: anUser
	"I return true if the login already exists."
	| userTemp |
	userTemp := self searchByLogin: anUser login.
	(userTemp isNil)
		ifTrue:[^ false]
		ifFalse:[^ true].
	! !

!Users class methodsFor: 'as yet unclassified' stamp: 'has 6/2/2013 19:32'!
remove: anUser
	(self database includes: anUser)
		ifTrue:[OCMSDB commit: [self database remove: anUser]]
		ifFalse:[self error: 'This user does not exist'].! !

!Users class methodsFor: 'as yet unclassified' stamp: 'has 6/2/2013 19:19'!
searchByLogin: aLogin
	"return an user with the login typed or nil"
	| reader |
	reader := self database where: [:each | each login = aLogin].
	(reader isEmpty not)
		ifTrue:[^ reader first].
		^ nil.! !

!Users class methodsFor: 'as yet unclassified' stamp: 'has 6/2/2013 19:22'!
searchByName: aName
	"I return a collection with users that contain the typed name"
	| reader |
	reader := self database where: [:each | each name from: aName to: aName maAlphabeticalNext].
	^ reader.! !

!Users class methodsFor: 'as yet unclassified' stamp: 'has 6/2/2013 19:34'!
update: anUser
	(self database includes: anUser)
		ifTrue:[
				OCMSDB commit: [
					self database remove: anUser.
					self database add: anUser].
				]
		ifFalse:[self error: 'This user does not exist'].! !
